@@ -10,6 +10,8 @@ pub struct Mp4BoxHeader {
 pub name: u32,
     /// Size of the box in bytes
 pub size: u64,
+    /// Offset to the start of the contained data (or header size).
+pub offset: u64,
 }
 
 /// File type box 'ftyp'.
@@ -23,6 +25,7 @@ pub struct Mp4FileTypeBox {
 
 extern crate byteorder;
 use byteorder::{BigEndian, ReadBytesExt};
+use std::io::{Result, Seek, SeekFrom};
 
 /// Parse a box out of a data buffer.
 pub fn read_box_header<T: ReadBytesExt>(src: &mut T) -> Option<Mp4BoxHeader> {
@@ -36,12 +39,26 @@ pub fn read_box_header<T: ReadBytesExt>(src: &mut T) -> Option<Mp4BoxHeader> {
     if tmp_size == 1 {
         assert!(size >= 16);
     }
+    let offset = match tmp_size {
+        1 => 4 + 4 + 8,
+        _ => 4 + 4,
+    };
+    assert!(offset <= size);
     Some(Mp4BoxHeader{
         name: name,
         size: size,
+        offset: offset,
     })
 }
 
+/// Skip over the contents of a box.
+pub fn skip_box_content<T: ReadBytesExt + std::io::Seek>
+  (src: &mut T, header: &Mp4BoxHeader)
+  -> std::io::Result<u64>
+{
+    src.seek(SeekFrom::Current((header.size - header.offset) as i64))
+}
+
 /// Parse an ftype box.
 pub fn read_ftyp<T: ReadBytesExt>(src: &mut T) -> Option<Mp4FileTypeBox> {
     let head = read_box_header(src).unwrap();
